#ifndef GAME_H
#define GAME_H

#include "client/input/Controller.h"
#include "gaming-core/utils/Clock.h"
#include "client/rendering/RenderSettings.h"
#include "client/rendering/Renderer.h"
#include "client/rendering/FontRenderer.h"
#include "common/world/World.h"
#include "common/block/BlockRegistry.h"
#include "rendering/renderer/WorldRenderer.h"
#include "gaming-core/utils/Size.h"

class Game final {
public:
    Game(const Controller& controller, const Clock& fps, const Clock& tps, RenderSettings& renderSettings, const Size& size);

    void tick();
    void renderWorld(float lag, Renderer& renderer);
    void renderWorldLines(float lag, Renderer& renderer);
    void renderTextOverlay(float lag, Renderer& renderer, FontRenderer& fr);

    bool isRunning() const;

private:
    const Controller& controller;
    const Clock& fps;
    const Clock& tps;
    RenderSettings& renderSettings;
    const Size& size;

    Vector3 lastPos;
    Vector3 pos;
    Quaternion lastRotation;
    Quaternion rotation;

    BlockRegistry blockRegistry;
    World world;

    WorldRenderer worldRenderer;
};

#endif